@@ -1,13 +1,16 @@
-#include <Rcpp.h>
+#include <cpp11/doubles.hpp>
+#include <cpp11/matrix.hpp>
+#include <deque>
 #include "vector.h"
 #include "quadTree.h"
 
-using namespace Rcpp;
-
-//[[Rcpp::export]]
-NumericMatrix collision(NumericMatrix pos, NumericMatrix vel, NumericVector radii, double strength) {
+[[cpp11::register]]
+cpp11::writable::doubles_matrix<> collision_c(cpp11::doubles_matrix<> pos,
+                                              cpp11::doubles_matrix<> vel,
+                                              cpp11::doubles radii,
+                                              double strength) {
   size_t i;
-  NumericMatrix res(pos.nrow(), pos.ncol());
+  cpp11::writable::doubles_matrix<> res(pos.nrow(), pos.ncol());
   QuadTree<2> tree;
   std::deque<Body<2> *> bodies;
   for (i = 0; i < pos.nrow(); ++i) {
